==> haskell-data-accessor-transformers-0.2.1.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-accessor-transformers
version:              0.2.1.8
visibility:           public
id:                   data-accessor-transformers-0.2.1.8-BKcRG5MDImJ1wUBCDVDCRs
key:                  data-accessor-transformers-0.2.1.8-BKcRG5MDImJ1wUBCDVDCRs
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  87a3d7dcaaa30399e2d36ff8e9ee70a4
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/data-accessor-transformers-0.2.1.8

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/data-accessor-transformers-0.2.1.8

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-accessor-transformers
hs-libraries:         HSdata-accessor-transformers-0.2.1.8-BKcRG5MDImJ1wUBCDVDCRs
depends:
    base-4.16.4.0 data-accessor-0.2.3.1-CQmiMUStWR5517QNMlpHTN
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-transformers-0.2.1.8-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-accessor-transformers
version:              0.2.1.8
visibility:           public
id:                   data-accessor-transformers-0.2.1.8-JUKMGGYlBpuGZRkQMO4s0r
key:                  data-accessor-transformers-0.2.1.8-JUKMGGYlBpuGZRkQMO4s0r
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  741580955c89dec589772cead62675a0
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-accessor-transformers-0.2.1.8

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-accessor-transformers-0.2.1.8

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-accessor-transformers-0.2.1.8

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-accessor-transformers
hs-libraries:         HSdata-accessor-transformers-0.2.1.8-JUKMGGYlBpuGZRkQMO4s0r
depends:
    base-4.17.2.1 data-accessor-0.2.3.1-6EVodzgBVFdDG6WCBPJrxZ
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
